@@ -18,11 +18,8 @@
               **************************************************
 
     If you get an error saying "wxUSE_FOO must be defined", it means that you
-    are not using the correct up-to-date version of setup.h. This happens most
-    often when using git or snapshots and a new symbol was added to setup0.h
-    and you haven't updated your local setup.h to reflect it. If this is the
-    case, you need to propagate the changes from setup0.h to your setup.h and,
-    if using makefiles under MSW, also remove setup.h under the build directory
+    are not using the correct up-to-date version of setup.h. If you're building
+    using makefiles under MSW, also remove setup.h under the build directory
     (lib/$(COMPILER)_{lib,dll}/msw[u][d][dll]/wx) so that the new setup.h is
     copied there.
 
@@ -649,6 +646,14 @@
 #   endif
 #endif /* !defined(wxUSE_DATAVIEWCTRL) */
 
+#ifndef wxUSE_NATIVE_DATAVIEWCTRL
+#   ifdef wxABORT_ON_CONFIG_ERROR
+#       error "wxUSE_NATIVE_DATAVIEWCTRL must be defined, please read comment near the top of this file."
+#   else
+#       define wxUSE_NATIVE_DATAVIEWCTRL 1
+#   endif
+#endif /* !defined(wxUSE_NATIVE_DATAVIEWCTRL) */
+
 #ifndef wxUSE_DATEPICKCTRL
 #   ifdef wxABORT_ON_CONFIG_ERROR
 #       error "wxUSE_DATEPICKCTRL must be defined, please read comment near the top of this file."
@@ -919,6 +924,14 @@
 #   endif
 #endif /* !defined(wxUSE_MDI_ARCHITECTURE) */
 
+#ifndef wxUSE_MENUBAR
+#   ifdef wxABORT_ON_CONFIG_ERROR
+#       error "wxUSE_MENUBAR must be defined, please read comment near the top of this file."
+#   else
+#       define wxUSE_MENUBAR 0
+#   endif
+#endif /* !defined(wxUSE_MENUBAR) */
+
 #ifndef wxUSE_MENUS
 #   ifdef wxABORT_ON_CONFIG_ERROR
 #       error "wxUSE_MENUS must be defined, please read comment near the top of this file."
@@ -1231,6 +1244,14 @@
 #   endif
 #endif /* !defined(wxUSE_VALIDATORS) */
 
+#ifndef wxUSE_WEBREQUEST
+#   ifdef wxABORT_ON_CONFIG_ERROR
+#       error "wxUSE_WEBREQUEST must be defined, please read comment near the top of this file."
+#   else
+#       define wxUSE_WEBREQUEST 0
+#   endif
+#endif /* !defined(wxUSE_WEBREQUEST) */
+
 #ifndef wxUSE_WEBVIEW
 #   ifdef wxABORT_ON_CONFIG_ERROR
 #       error "wxUSE_WEBVIEW must be defined, please read comment near the top of this file."
@@ -2120,6 +2141,7 @@
 #   if wxUSE_FONTDLG || \
        wxUSE_FILEDLG || \
        wxUSE_CHOICEDLG || \
+       wxUSE_CREDENTIALDLG || \
        wxUSE_NUMBERDLG || \
        wxUSE_TEXTDLG || \
        wxUSE_DIRDLG || \
@@ -2253,14 +2275,25 @@
 #   endif
 #endif /* wxUSE_SVG */
 
-#if wxUSE_TASKBARICON && !wxUSE_MENUS
-#   ifdef wxABORT_ON_CONFIG_ERROR
-#       error "wxUSE_TASKBARICON requires wxUSE_MENUS"
-#   else
-#       undef wxUSE_TASKBARICON
-#       define wxUSE_TASKBARICON 0
-#   endif
-#endif /* wxUSE_TASKBARICON */
+#if !wxUSE_MENUS
+#   if wxUSE_MENUBAR
+#      ifdef wxABORT_ON_CONFIG_ERROR
+#          error "wxUSE_MENUBAR requires wxUSE_MENUS"
+#      else
+#          undef wxUSE_MENUBAR
+#          define wxUSE_MENUBAR 0
+#      endif
+#   endif /* wxUSE_MENUBAR */
+
+#   if wxUSE_TASKBARICON
+#      ifdef wxABORT_ON_CONFIG_ERROR
+#          error "wxUSE_TASKBARICON requires wxUSE_MENUS"
+#      else
+#          undef wxUSE_TASKBARICON
+#          define wxUSE_TASKBARICON 0
+#      endif
+#   endif /* wxUSE_TASKBARICON */
+#endif /* !wxUSE_MENUS */
 
 #if !wxUSE_VARIANT
 #   if wxUSE_DATAVIEWCTRL
@@ -2282,7 +2315,8 @@
 #   endif
 #endif /* wxUSE_TREELISTCTRL */
 
-#if wxUSE_WEBVIEW && !(wxUSE_WEBVIEW_WEBKIT || wxUSE_WEBVIEW_WEBKIT2 || wxUSE_WEBVIEW_IE)
+#if wxUSE_WEBVIEW && !(wxUSE_WEBVIEW_WEBKIT || wxUSE_WEBVIEW_WEBKIT2 || \
+                       wxUSE_WEBVIEW_IE || wxUSE_WEBVIEW_EDGE)
 #   ifdef wxABORT_ON_CONFIG_ERROR
 #       error "wxUSE_WEBVIEW requires at least one backend"
 #   else
@@ -2291,6 +2325,15 @@
 #   endif
 #endif /* wxUSE_WEBVIEW && !any web view backend */
 
+#if wxUSE_WEBREQUEST && !(wxUSE_WEBREQUEST_WINHTTP || wxUSE_WEBREQUEST_URLSESSION || wxUSE_WEBREQUEST_CURL)
+#   ifdef wxABORT_ON_CONFIG_ERROR
+#       error "wxUSE_WEBREQUEST requires at least one backend"
+#   else
+#       undef wxUSE_WEBREQUEST
+#       define wxUSE_WEBREQUEST 0
+#   endif
+#endif /* wxUSE_WEBREQUEST && !any web request backend */
+
 #if wxUSE_PREFERENCES_EDITOR
     /*
         We can use either a generic implementation, using wxNotebook, or a
@@ -2383,6 +2426,17 @@
 #   endif
 #endif /* wxUSE_RICHTEXT */
 
+#if wxUSE_RICHTOOLTIP
+#   if !wxUSE_POPUPWIN
+#       ifdef wxABORT_ON_CONFIG_ERROR
+#           error "wxRichToolTip requires wxUSE_POPUPWIN"
+#       else
+#           undef wxUSE_POPUPWIN
+#           define wxUSE_POPUPWIN 1
+#       endif
+#   endif
+#endif /* wxUSE_RICHTOOLTIP */
+
 #if wxUSE_PROPGRID
 #   if !wxUSE_VARIANT
 #       ifdef wxABORT_ON_CONFIG_ERROR
@@ -2394,6 +2448,17 @@
 #   endif
 #endif /* wxUSE_PROPGRID */
 
+#if wxUSE_TIPWINDOW
+#   if !wxUSE_POPUPWIN
+#       ifdef wxABORT_ON_CONFIG_ERROR
+#           error "wxTipWindow requires wxUSE_POPUPWIN"
+#       else
+#           undef wxUSE_POPUPWIN
+#           define wxUSE_POPUPWIN 1
+#       endif
+#   endif
+#endif /* wxUSE_TIPWINDOW */
+
 #endif /* wxUSE_GUI */
 
 #endif /* _WX_CHKCONF_H_ */
