@@ -15,7 +15,7 @@
 #endif /* __cplusplus */
 
 /* the installation location prefix from configure */
-#define wxINSTALL_PREFIX "D:/bld/wxwidgets_1642514503261/_h_env/Library"
+#define wxINSTALL_PREFIX "D:/bld/wxwidgets_1643998584664/_h_env/Library"
 
 /* Define to `int' if <sys/types.h> doesn't define.  */
 #define gid_t int
@@ -182,8 +182,6 @@
     #define wxUSE_UNICODE 1
 #endif
 
-#define wxUSE_WCHAR_T 1
-
 
 #define wxUSE_EXCEPTIONS 1
 
@@ -296,6 +294,16 @@
 
 #define wxUSE_MIMETYPE 1
 
+#define wxUSE_WEBREQUEST 1
+
+#ifdef __APPLE__
+#define wxUSE_WEBREQUEST_URLSESSION wxUSE_WEBREQUEST
+#else
+#define wxUSE_WEBREQUEST_URLSESSION 0
+#endif
+
+#define wxUSE_WEBREQUEST_CURL 0
+
 #define wxUSE_PROTOCOL 1
 
 #define wxUSE_PROTOCOL_FILE 1
@@ -338,6 +346,8 @@
 #define wxUSE_WEBVIEW_IE 1
 #endif
 
+#define wxUSE_WEBVIEW_EDGE 0
+
 #if (defined(__WXGTK__) && !defined(__WXGTK3__)) || defined(__WXOSX__)
 #define wxUSE_WEBVIEW_WEBKIT 1
 #else
@@ -413,6 +423,8 @@
 #define wxUSE_TREECTRL 1
 #define wxUSE_TREELISTCTRL 1
 
+#define wxUSE_NATIVE_DATAVIEWCTRL 1
+
 #define wxUSE_STATUSBAR 1
 
 #define wxUSE_NATIVE_STATUSBAR 1
@@ -467,6 +479,8 @@
 
 #define wxUSE_MENUS 1
 
+#define wxUSE_MENUBAR 1
+
 #define wxUSE_NOTIFICATION_MESSAGE 1
 
 #define wxUSE_PREFERENCES_EDITOR 1
@@ -519,6 +533,8 @@
 
 #define wxUSE_NUMBERDLG 1
 
+#define wxUSE_CREDENTIALDLG 1
+
 #define wxUSE_SPLASH 1
 
 #define wxUSE_WIZARDDLG 1
@@ -545,6 +561,8 @@
 
 #define wxUSE_GLCANVAS 1
 
+#define wxUSE_GLCANVAS_EGL 0
+
 #define wxUSE_RICHTEXT 1
 
 
@@ -629,7 +647,6 @@
 #define wxUSE_THEME_MONO 0
 #define wxUSE_THEME_WIN32 0
 
-
 /* --- end common options --- */
 
 /*
@@ -674,6 +691,8 @@
     #define wxUSE_GRAPHICS_DIRECT2D 1
 #endif
 
+#define wxUSE_WEBREQUEST_WINHTTP 1
+
 
 #define wxUSE_OLE 1
 
@@ -738,11 +757,6 @@
  */
 /* #undef VA_LIST_IS_ARRAY */
 
-/*
- * Define if the compiler supports variadic macros
- */
-#define HAVE_VARIADIC_MACROS 1
-
 /*
  * Define if you don't want variadic macros to be used even if they are
  * supported by the compiler.
@@ -756,7 +770,7 @@
 /*
  * Define if your compiler has compliant std::string::compare
  */
-/* #undef HAVE_STD_STRING_COMPARE */
+#define HAVE_STD_STRING_COMPARE 1
 /*
  * Define if your compiler has <hash_map>
  */
@@ -777,12 +791,12 @@
 /*
  * Define if your compiler has std::unordered_map
  */
-/* #undef HAVE_STD_UNORDERED_MAP */
+#define HAVE_STD_UNORDERED_MAP 1
 
 /*
  * Define if your compiler has std::unordered_set
  */
-/* #undef HAVE_STD_UNORDERED_SET */
+#define HAVE_STD_UNORDERED_SET 1
 
 /*
  * Define if your compiler has std::tr1::unordered_map
@@ -983,9 +997,6 @@
 /* Define if you have pthread_attr_setstacksize */
 /* #undef HAVE_PTHREAD_ATTR_SETSTACKSIZE */
 
-/* Define if you have shl_load() */
-/* #undef HAVE_SHL_LOAD */
-
 /* Define if you have snprintf() */
 /* #undef HAVE_SNPRINTF */
 
@@ -1041,7 +1052,7 @@
 /* #undef HAVE_WCSNCASECMP */
 
 /* Define if you have wcslen function  */
-/* #undef HAVE_WCSLEN */
+#define HAVE_WCSLEN 1
 
 /* Define if you have wcsdup function  */
 #define HAVE_WCSDUP 1
@@ -1088,9 +1099,6 @@
 /* Define if wchar_t is distinct type in your compiler. */
 #define wxWCHAR_T_IS_REAL_TYPE 1
 
-/* Define if you have the dlerror function.  */
-/* #undef HAVE_DLERROR */
-
 /* Define if you have the dladdr function.  */
 /* #undef HAVE_DLADDR */
 
@@ -1202,9 +1210,6 @@
 /* Define if you have the <langinfo.h> header file.  */
 /* #undef HAVE_LANGINFO_H */
 
-/* Define if you have the <w32api.h> header file (mingw,cygwin).  */
-/* #undef HAVE_W32API_H */
-
 /* Define if you have the <sys/soundcard.h> header file. */
 /* #undef HAVE_SYS_SOUNDCARD_H */
 
